# Topsis-Aadihri-102083030
It takes the dataset and calculates the TOPSIS and assign the topsis score and rank!

## Installation
```pip install Topsis-Aadishri-102083030```

## How to use it?
Open terminal Write:
```Topsis <inputFilename.csv> <"Weights"> <"Impacts"> <outputFilename.csv>```

## License

© 2022 Aadishri Soni

This repository is licensed under the MIT license. See LICENSE for details.